@@ -24,6 +24,7 @@ def collect_plugins(
             as a plugin
         assert_one_per_source (bool): asserts that only 1 plugin may be
             defined in each source file
+            
     Returns:
         List[str]: a list of all the plugin files collected. should be
             stored in the calling files `__all__` variable
@@ -31,7 +32,7 @@ def collect_plugins(
     exports = []
 
     # iterate through the modules in the current package
-    package_dir = Path(registering_file).resolve().parent
+    package_dir = str(Path(registering_file).resolve().parent)
     for (_, module_name, _) in iter_modules([package_dir]):
 
         # import the module and iterate through its attributes
